@@ -18,10 +18,6 @@ class TestRisk(unittest.TestCase):
             risk.cython_estimate_downside_risk(ts, S, 0.0),
             0.0
         )
-        self.assertAlmostEqual(
-            risk.fortranrisk.fortran_estimate_downside_risk(ts, S, 0.0),
-            0.0
-        )
 
     def test_somedownward_movement(self):
         r_fake_array = np.array([0.1, 0.2, -0.1, -0.1, 0.3, 0.4])
@@ -37,10 +33,6 @@ class TestRisk(unittest.TestCase):
             risk.cython_estimate_downside_risk(ts, S_array, 0.0),
             expected_downside_risk
         )
-        self.assertAlmostEqual(
-            risk.fortranrisk.fortran_estimate_downside_risk(ts, S_array, 0.0),
-            expected_downside_risk
-        )
 
     def test_noupward_movement(self):
         ts = np.linspace(0, 10, 11)
@@ -54,10 +46,6 @@ class TestRisk(unittest.TestCase):
             risk.cython_estimate_upside_risk(ts, S, 0.0),
             0.0
         )
-        self.assertAlmostEqual(
-            risk.fortranrisk.fortran_estimate_upside_risk(ts, S, 0.0),
-            0.0
-        )
 
     def test_someupward_movement(self):
         r_fake_array = np.array([-0.1, -0.2, 0.1, 0.1, -0.3, -0.4])
@@ -73,10 +61,6 @@ class TestRisk(unittest.TestCase):
             risk.cython_estimate_upside_risk(ts, S_array, 0.0),
             expected_upside_risk
         )
-        self.assertAlmostEqual(
-            risk.fortranrisk.fortran_estimate_upside_risk(ts, S_array, 0.0),
-            expected_upside_risk
-        )
 
     def test_beta(self):
         timestamps = np.array(['2021-02-16T00:00:00.000000000', 
